# MMF-meta
Эта библиотека - часть проекта Model Management Framework.

Отвечает за serving

### Пример использования
```shell
mmfserve serve_rabbit --n_proc=2 --queue_name=tasks_que --results_exchange=result_exchange main.py
```

[Подробная документация](https://mm-framework.github.io/docs/)
